@@ -1,20 +1,22 @@
 #' Standard deviation of a field among points within polygons
 #'
 #' Calculates the population standard deviation (i.e. denominator = n,
-#' not n-1) of values from \code{\link{data-Point}}'s within a set of
-#' \code{\link{data-Polygon}}'s
+#' not n-1) of values from [data-Point]'s within a set of
+#' [data-Polygon]'s
 #'
 #' @export
-#' @param polygons Polygon(s) defining area to aggregate.
-#' @param points Points with values to aggregate.
-#' @param in_field Characater for the name of the field on \code{pts} on
-#' which you wish to perfrom the aggregation
-#' @param out_field Characater for the name of the field on the ouput
+#' @param polygons Polygon(s) ([data-FeatureCollection]<([data-Polygon])>)
+#' defining area to aggregate
+#' @param points Points ([data-FeatureCollection]<([data-Point])>) with
+#' values to aggregate
+#' @param in_field Character for the name of the field on `pts` on
+#' which you wish to perform the aggregation.
+#' @param out_field Character for the name of the field on the output
 #' polygon FeatureCollection that will store the resultant value.
 #' @template lint
 #' @family aggregations
 #' @return polygons with appended field representing deviation, as a
-#' \code{\link{data-FeatureCollection}}
+#' [data-FeatureCollection]
 #'
 #' @author Jeff Hollister \email{hollister.jeff@@epa.gov}
 #' @examples \dontrun{
@@ -24,7 +26,15 @@
 #' }
 lawn_deviation <- function(polygons, points, in_field, out_field = "deviation",
                            lint = FALSE) {
+  # This code has been contributed by Jeff Hollister, US EPA
+  # Please read the following disclaimer:
+  # \url{https://www.epa.gov/home/github-contribution-disclaimer}
+
   lawnlint(list(polygons, points), lint)
+  if (lint) {
+    is_type(polygons, type_top = "FeatureCollection")
+    is_type(points, type_top = "FeatureCollection")
+  }
   calc_math("standardDeviation", convert(polygons), convert(points),
             in_field, out_field)
 }
