@@ -1,9 +1,9 @@
 #' Flip x,y to y,x, and vice versa
 #'
 #' @export
-#' @param input Feature of features
+#' @param input [data-Feature] or [data-FeatureCollection]
 #' @template lint
-#' @return a \code{\link{data-Feature}} or \code{\link{data-FeatureCollection}}
+#' @return A [data-Feature] or [data-FeatureCollection]
 #' @examples
 #' # a point
 #' serbia <- '{
@@ -28,6 +28,7 @@
 lawn_flip <- function(input, lint = FALSE) {
   input <- convert(input)
   lawnlint(input, lint)
+  if (lint) is_type(input, type_top = c("Feature", "FeatureCollection"))
   ct$eval(sprintf("var flp = turf.flip(%s);", input))
   structure(ct$get("flp"), class = tolower(ct$get("flp.type")))
 }
