@@ -1,14 +1,14 @@
 #' Get a point midway between two points
 #'
-#' Takes two \code{\link{data-Point}}'s and returns a point midway
+#' Takes two [data-Point]'s and returns a point midway
 #' between them
 #'
 #' @export
-#' @param pt1 First point
-#' @param pt2 Second point
+#' @param pt1 First [data-Feature]<([data-Point])>
+#' @param pt2 Second [data-Feature]<([data-Point])>
 #' @template lint
 #' @family measurements
-#' @return A \code{\link{data-Point}} midway between pt1 and pt2
+#' @return A [data-Feature]<([data-Point])> midway between pt1 and pt2
 #' @examples
 #' pt1 <- '{
 #'   "type": "Feature",
@@ -39,6 +39,10 @@ lawn_midpoint <- function(pt1, pt2, lint = FALSE) {
   pt1 <- convert(pt1)
   pt2 <- convert(pt2)
   lawnlint(list(pt1, pt2), lint)
+  if (lint) {
+    is_type(pt1, type_top = "Feature", type_lower = "Point")
+    is_type(pt2, type_top = "Feature", type_lower = "Point")
+  }
   ct$eval(sprintf("var md = turf.midpoint(%s, %s);", pt1, pt2))
   structure(ct$get("md"), class = "point")
 }
