@@ -4,17 +4,19 @@
 #' box that would contain the input.
 #'
 #' @export
-#' @param bbox A bounding box
+#' @param bbox A bounding box.
 #' @family measurements
-#' @return A square surrounding bbox, numeric vector of length four
+#' @return A square surrounding bbox, numeric vector of length four.
 #' @examples
 #' bbox <- c(-20, -20, -15, 0)
 #' lawn_square(bbox)
 #' @examples \dontrun{
 #' sq <- lawn_square(bbox)
-#' lawn_featurecollection(list(lawn_bbox_polygon(bbox), lawn_bbox_polygon(sq))) %>% view
+#' lawn_featurecollection(list(lawn_bbox_polygon(bbox),
+#'   lawn_bbox_polygon(sq))) %>% view
 #' }
 lawn_square <- function(bbox) {
+  assert(bbox, c('numeric', 'integer'))
   ct$eval(sprintf("var sq = turf.square(%s);", convert(bbox)))
   ct$get("sq")
 }
