@@ -1,16 +1,16 @@
 #' Create a Triangulated Irregular Network
 #'
-#' Takes a set of \code{\link{data-Point}}'s and the name of a z-value property
-#' and creates a Triangulated Irregular Network (TIN)
+#' Takes a set of [data-Point]'s and the name of a z-value property
+#' and creates a Triangulated Irregular Network (TIN).
 #'
 #' @export
-#' @param pt input points
-#' @param propertyName name of the property from which to pull z values This is
-#' optional: if not given, then there will be no extra data added to the derived
-#' triangles.
+#' @param pt Input points.
+#' @param propertyName (character) Name of the property from which to pull z
+#' values. This is optional: if not given, then there will be no extra data
+#' added to the derived triangles
 #' @template lint
 #' @family interpolation
-#' @return TIN output, as a \code{\link{data-FeatureCollection}}
+#' @return TIN output, as a [data-FeatureCollection].
 #' @details Data returned as a collection of Polygons. These are often used for
 #' developing elevation contour maps or stepped heat visualizations.
 #'
@@ -27,6 +27,7 @@
 lawn_tin <- function(pt, propertyName = NULL, lint = FALSE) {
   pt <- convert(pt)
   lawnlint(pt, lint)
+  assert(propertyName, 'character')
   ct$eval(sprintf("var tin = turf.tin(%s, '%s');", pt, convert(propertyName)))
   as.fc(ct$get("tin"))
 }
