@@ -76,6 +76,7 @@ test_that("lawn_concave works", {
 test_that("lawn_concave fails correctly", {
   expect_error(lawn_concave(), "argument \"points\" is missing, with no default")
   expect_error(lawn_concave("a"), "a is not defined")
+  expect_error(lawn_concave("a", lint = TRUE), "invalid char")
   expect_error(lawn_concave(points, "stuff"), "stuff is not defined")
-  expect_error(lawn_concave(points, 1, "stuff"), "Invalid unit")
+  expect_error(lawn_concave(points, 1, "stuff"), "units is invalid")
 })
