@@ -1,9 +1,12 @@
 context("lawn_tag")
 
-pts <- lawn_random(n = 30)
-polys <- lawn_triangle_grid(c(-77.3876, 38.7198, -76.9482, 39.0277), 30, 'miles')
-polys$features$properties <-
-    data.frame(fill = c("#f92", "#295"), stroke = 1:2, `fill-opacity` = 2:3)
+bbox <- c(0, 0, 10, 10)
+pts <- lawn_random(n = 30, bbox = bbox)
+polys <- lawn_triangle_grid(bbox, 50, 'miles')
+polys$features$properties$fill <- "#f92"
+polys$features$properties$stroke <- 0
+polys$features$properties$`fill-opacity` <- 1
+
 a <- lawn_tag(pts, polys, 'fill', 'marker-color')
 
 test_that("lawn_tag returns correct classes", {
@@ -13,11 +16,14 @@ test_that("lawn_tag returns correct classes", {
   expect_is(a$features$geometry$type, "character")
   expect_is(a$features$geometry$coordinates, "list")
   expect_equal(a$features$geometry$type[1], "Point")
+
+  expect_is(a$features$properties, "data.frame")
+  expect_named(a$features$properties, "marker-color")
+  expect_equal(a$features$properties$`marker-color`[1], "#f92")
 })
 
-test_that("polyId, containingPolyId parameters works as expected", {
-  # no properties given
-  expect_equal(length(lawn_tag(pts, polys, 'fill', 'marker-color')$features$properties), 0)
+test_that("polyId, out_field parameters works as expected", {
+  expect_named(lawn_tag(pts, polys, 'fill', 'stuff')$features$properties, "stuff")
 })
 
 test_that("lawn_tag fails correctly", {
@@ -26,6 +32,3 @@ test_that("lawn_tag fails correctly", {
   # wrong geojson input
   expect_error(lawn_tag(pts, "{}", 'fill', 'marker-color'), "Cannot call method")
 })
-
-### FIX ME - need to add more tests here, including after fixing
-### https://github.com/ropensci/lawn/issues/30
\ No newline at end of file
